# Behave-prophet (Behavior testing for Prophet)

![logo](logo.png)

# Prophet Behavior Testing

[![codecov](https://codecov.io/gh/franperic/flair/graph/badge.svg?token=6P7C5HHPOC)](https://codecov.io/gh/franperic/flair)

# Getting started

Check out this [blogpost](https://franperic.github.io/posts/flair/) for an introduction to behavior testing in the context of time series foreacsting.

In the subfolder `examples` you can find a simple example of how to use this library.

This project was inspired by [this blogpost](https://www.jeremyjordan.me/testing-ml/) about testing machine learning models.
